/*
 * Chimères Orchestra
 * http://reso-nance.org/chimeres-orchestra 
 *
 * Setup : Ethernet (OSC) > Ethernet Shield > Arduino MEGA > MOSFETS > DC Motors
 * 
 * OSC message : /arm Id (int 0-5), PWM (int 0-255), Delay (int 0-100)
 * 
*/
#include <SPI.h>
#include <Ethernet.h>
//#include <EthernetUdp2.h>
//#include <Ethernet2.h>
#include <ArdOSC.h>

#include "PwmMotor.h"

// ---- NETWORK ---- //
byte myIp[] = { 192, 168, 1, 106 }; // IP
byte myMac[] = { 0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED }; // MAC address
int serverPort = 8888; // Receive port
OSCServer server; // to receive messages
char oscmsg[]="/arm";

// ---- CONFIGURATIONS ---- //
const int PINS[] = {2,3,5,6,7,8}; // pins Mosfets Shield (for MEGA because Ethernet Shield use 10,11,12,13 pin and 4th pin for SD Card)
const int TIME_MAX = 120; //2000;
const int NB = 6;
const int TEMPO = 10; // sampling tempo
const boolean DEBUG = false;
const boolean SENSOR_ACTIVE = false;


// ---- MOTORS --------- //
int motor_id, motor_pwm, motor_time;
PwmMotor motors[NB];
unsigned long current = 0;

/*
// ----DIGITAL SENSOR (PIR) --------- //
unsigned long button_interval = 50;
unsigned long button_previous = 0;
int button_state = 0;
int button_last_state = 0;
int button_pin = 2; //2,4,7,8,12,13 
*/

// ---- SETUP ----------- //
void setup() {
 Ethernet.begin(myMac,myIp); 
 server.begin(serverPort);
 server.addCallback(oscmsg,&get_osc); // callback function (receive)

 for (int i=0; i < NB; i++) {
     motors[i].init(PINS[i], TIME_MAX, DEBUG);
  }
}

// ---- PROGRAM ----------- //
void loop() {
  // UPDATE TIME
  current = millis();

  if(server.availableCheck()>0){
    // alive 
    }


  /*
  // SENSOR
  if (SENSOR_ACTIVE) {
    if(current - button_previous > button_interval) { // sampling
     button_previous = current; 
     button_state = digitalRead(button_pin);
     if (button_state != button_last_state) { // if the state has changed
       Serial.println(button_state);
     }
     button_last_state = button_state;
    }
  }
  */

  // MOTOR ON
  while (Serial.available()) {
     motor_id = Serial.parseInt(); 
     motor_pwm = Serial.parseInt();
     motor_time = Serial.parseInt();
     if (Serial.read() == '\n') {
       if( motors[motor_id].isOn() == false )  motors[motor_id].on(current, motor_pwm, motor_time);
     }
   }
   
  
  // MOTOR OFF
  for (int i=0; i < NB; i++) {
     if( motors[i].isOn() ) motors[i].off(current);
  }

  delay(TEMPO);
}

// Get content message
void get_osc(OSCMessage *_mes){
  motor_id=_mes->getArgInt32(0);
  motor_pwm=_mes->getArgInt32(1);
  motor_time=_mes->getArgInt32(2);

  if( motors[motor_id].isOn() == false )  motors[motor_id].on(current, motor_pwm, motor_time);
}
