/*
 * Chimères Orchestra
 * http://reso-nance.org/chimeres-orchestra 
 *
 * Setup #1 : Raspberry Pi > Pd > Serial > Arduino MEGA > MOSFETS > DC Motors
 * Setup #2 : Udoo > Pd > Serial > Arduino DUE > MOSFETS > DC Motors
 * 
 * Serial message : Id (int 0-5), PWM (int 0-255), Delay (int 0-100)
 * 
*/

#include "PwmMotor.h"

// ---- CONFIGURATIONS ---- //
const int PINS[] = {3,5,6,9,10,11}; // pins Mosfets Shield
const int TIME_MAX = 130;
const int NB = 6;
const int TEMPO = 5; // sampling tempo
const boolean DEBUG = false;
const boolean SENSOR_ACTIVE = false;

// ---- MOTORS --------- //
int motor_id, motor_pwm, motor_time;
PwmMotor motors[NB];
unsigned long current = 0;

// ----DIGITAL SENSOR (PIR) --------- //
unsigned long button_interval = 50;
unsigned long button_previous = 0;
int button_state = 0;
int button_last_state = 0;
int button_pin = 2; //2,4,7,8,12,13 

// ---- PROGRAM ----------- //
void setup() {
  Serial.begin(38400);
   for (int i=0; i < NB; i++) {
     motors[i].init(PINS[i], TIME_MAX, DEBUG);
  }
}

void loop() {
  // UPDATE TIME
  current = millis();
  
  // SENSOR
  if (SENSOR_ACTIVE) {
    if(current - button_previous > button_interval) { // sampling
     button_previous = current; 
     button_state = digitalRead(button_pin);
     if (button_state != button_last_state) { // if the state has changed
       Serial.println(button_state);
     }
     button_last_state = button_state;
    }
  }

  // MOTOR ON
  while (Serial.available()) {
     motor_id = Serial.parseInt(); 
     motor_pwm = Serial.parseInt();
     motor_time = Serial.parseInt();
     if (Serial.read() == '\n') {
       if( motors[motor_id].isOn() == false )  motors[motor_id].on(current, motor_pwm, motor_time);
     }
   }
  
  // MOTOR OFF
  for (int i=0; i < NB; i++) {
     if( motors[i].isOn() ) motors[i].off(current);
  }
  
  delay(TEMPO);
}
